import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,    
    
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import BasStationCreate from "./BasStationCreate";
import BasStationPanel from "./BasStationPanel";
import EmptyData from "../../components/EmptyData";
import MyCreateButton from "../../components/MyCreateButton";
import MyExportButton from '../../components/MyExportButton';
import PageDrawer from "../../components/PageDrawer";
import MyField from "../../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';
import WarehouseAreaField from "./WarehouseAreaField";
import CrossZoneAreaField from "./CrossZoneAreaField";

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <TextInput source="stationName" label="table.field.basStation.stationName" />,
    <NumberInput source="inAble" label="table.field.basStation.inAble" />,
    <NumberInput source="outAble" label="table.field.basStation.outAble" />,
    <TextInput source="useStatus" label="table.field.basStation.useStatus" />,
    <NumberInput source="area" label="table.field.basStation.area" />,
    <NumberInput source="isCrossZone" label="table.field.basStation.isCrossZone" />,
    <TextInput source="crossZoneArea" label="table.field.basStation.crossZoneArea" />,
    <NumberInput source="isWcs" label="table.field.basStation.isWcs" />,
    <TextInput source="wcsData" label="table.field.basStation.wcsData" />,
    <NumberInput source="containerType" label="table.field.basStation.containerType" />,
    <TextInput source="barcode" label="table.field.basStation.barcode" />,
    <NumberInput source="autoTransfer" label="table.field.basStation.autoTransfer" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const BasStationList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);
    const [areaFieldDialog, setAreaFieldDialog] = useState(false);
    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.basStation"}
                empty={false}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <MyCreateButton onClick={() => { setCreateDialog(true) }} />
                        <SelectColumnsButton preferenceKey='basStation' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='basStation'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}                    
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <TextField source="stationName" label="table.field.basStation.stationName" />
                    <FunctionField
                        source="inAble"
                        label="table.field.basStation.inAble"
                        render={record => record.inAble === 1 ? '是' : '否'}
                    />                    
                    <FunctionField
                        source="outAble"
                        label="table.field.basStation.outAble"
                        render={record => record.inAble === 1 ? '是' : '否'}
                    />
                    <TextField source="useStatus$" label="table.field.basStation.useStatus" />
                    <NumberField source="area$" label="table.field.basStation.area" />                    
                    <FunctionField
                        source="isCrossZone"
                        label="table.field.basStation.isCrossZone"
                        render={record => record.inAble === 1 ? '是' : '否'}
                    />
                    <WrapperField cellClassName="crossZoneArea" label="table.field.basStation.crossZoneArea">
                        <CrossZoneAreaField
                            open={areaFieldDialog}
                            setOpen={setAreaFieldDialog}                
                        />                        
                    </WrapperField> 
                    <FunctionField
                        source="isWcs"
                        label="table.field.basStation.isWcs"
                        render={record => record.inAble === 1 ? '是' : '否'}
                    />                    
                    <NumberField source="containerType$" label="table.field.basStation.containerType" />
                    <TextField source="barcode" label="table.field.basStation.barcode" />                    
                    <FunctionField
                        source="autoTransfer"
                        label="table.field.basStation.autoTransfer"
                        render={record => record.inAble === 1 ? '是' : '否'}
                    />
                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />                    
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">                        
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>                    
                </StyledDatagrid>
                
            </List>
            <BasStationCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            
            <PageDrawer
                title='BasStation Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default BasStationList;
